from checkov.common.models.consts import ANY_VALUE
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories


class CloudwatchLogGroupKMSKey(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that CloudWatch Group is encrypted by KMS"
        id = "CKV_AWS_158"
        supported_resources = ['aws_cloudwatch_log_group']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "kms_key_id"

    def get_expected_value(self):
        return ANY_VALUE


check = CloudwatchLogGroupKMSKey()



import json
import logging
from json import JSONDecodeError
from typing import TypeVar, List, overload, Union, Optional, Any, Dict

import yaml

T = TypeVar("T")


@overload
def force_list(var: List[T]) -> List[T]:
    ...


@overload
def force_list(var: T) -> List[T]:
    ...


def force_list(var: Union[T, List[T]]) -> List[T]:
    if not isinstance(var, list):
        return [var]
    return var


def force_int(var: Any) -> Optional[int]:
    try:
        if not isinstance(var, int):
            return int(var)
        return var
    except Exception:
        return None


def force_float(var: Any) -> Optional[float]:
    try:
        if not isinstance(var, float):
            return float(var)
        return var
    except Exception:
        return None


def convert_str_to_bool(bool_str: Union[bool, str]) -> Union[bool, str]:
    if bool_str in ["true", '"true"', "True", '"True"']:
        return True
    elif bool_str in ["false", '"false"', "False", '"False"']:
        return False
    else:
        return bool_str


def force_dict(obj: Any) -> Optional[Dict[str, Any]]:
    """
    If the specified object is a dict, returns the object. If the object is a list of length 1 or more, and the first
    element is a dict, returns the first element. Else returns None.
    :param obj:
    :return:
    """
    if isinstance(obj, dict):
        return obj
    if isinstance(obj, list) and len(obj) > 0 and isinstance(obj[0], dict):
        return obj[0]
    return None


def is_json(data: str) -> bool:
    try:
        parsed = json.loads(data)
        return isinstance(parsed, dict)
    except (TypeError, ValueError):
        logging.debug(f"could not parse json data: {data}")
        return False


def is_yaml(data: str) -> bool:
    try:
        parsed = yaml.safe_load(data)
        return isinstance(parsed, dict)
    except yaml.YAMLError:
        logging.debug(f"could not parse yaml data: {data}")
        return False


def extract_policy_dict(policy: Union[dict, str]) -> Optional[dict]:
    if isinstance(policy, dict):
        return policy
    if isinstance(policy, str):
        try:
            policy_dict = json.loads(policy)
            return policy_dict
        except JSONDecodeError:
            return None

    return None


from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceCheck


class MonitorLogProfileRetentionDays(BaseResourceCheck):
    def __init__(self):
        name = "Ensure audit profile captures all the activities"
        id = "CKV_AZURE_38"
        supported_resources = ['azurerm_monitor_log_profile']
        categories = [CheckCategories.LOGGING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        categories = ['Write', 'Delete', 'Action']
        res_categories = conf.get('categories')
        if isinstance(res_categories, list) and res_categories and \
                all(category in conf['categories'][0] for category in categories):
            return CheckResult.PASSED
        return CheckResult.FAILED


check = MonitorLogProfileRetentionDays()



from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.kubernetes.base_spec_check import BaseK8Check

class WildcardRoles(BaseK8Check):
    # CIS-1.6 5.1.3
    def __init__(self):
        name = "Minimize wildcard use in Roles and ClusterRoles"
        id = "CKV_K8S_49"
        categories = [CheckCategories.KUBERNETES]
        supported_kind = ['Role', 'ClusterRole']
        super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)

    def get_resource_id(self, conf):
        if "namespace" in conf["metadata"]:
            return "{}.{}.{}".format(conf["kind"], conf["metadata"]["name"], conf["metadata"]["namespace"])
        else:
            return "{}.{}.default".format(conf["kind"], conf["metadata"]["name"])

    def scan_spec_conf(self, conf):
        if isinstance(conf.get("rules"), list) and len(conf.get("rules")) > 0:
            if "apiGroups" in conf["rules"][0]:
                if any("*" in s for s in conf["rules"][0]["apiGroups"]):
                    return CheckResult.FAILED
            if "resources" in conf["rules"][0]:
                if any("*" in s for s in conf["rules"][0]["resources"]):
                    return CheckResult.FAILED
            if "verbs" in conf["rules"][0]:
                if any("*" in s for s in conf["rules"][0]["verbs"]):
                    return CheckResult.FAILED

        return CheckResult.PASSED

check = WildcardRoles()



from abc import abstractmethod
from typing import List, Dict, Any

import dpath.util
import re
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.common.models.consts import ANY_VALUE
from checkov.common.util.type_forcers import force_list
from checkov.terraform.parser_utils import find_var_blocks


class BaseResourceValueCheck(BaseResourceCheck):
    def __init__(
        self,
        name: str,
        id: str,
        categories: List[CheckCategories],
        supported_resources: List[str],
        missing_block_result: CheckResult = CheckResult.FAILED,
    ) -> None:
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
        self.missing_block_result = missing_block_result

    @staticmethod
    def _filter_key_path(path: str) -> List[str]:
        """
        Filter an attribute path to contain only named attributes by dropping array indices from the path)
        :param path: valid JSONPath of an attribute
        :return: List of named attributes with respect to the input JSONPath order
        """
        return [x for x in path.split("/") if not re.search(r"^\[?\d+]?$", x)]

    @staticmethod
    def _is_variable_dependant(value: Any) -> bool:
        if not isinstance(value, str):
            return False
        if "${" not in value:
            return False

        if find_var_blocks(value):
            return True
        return False

    @staticmethod
    def _is_nesting_key(inspected_attributes: List[str], key: List[str]) -> bool:
        """
        Resolves whether a key is a subset of the inspected nesting attributes
        :param inspected_attributes: list of nesting attributes
        :param key: JSONPath key of an attribute
        :return: True/False
        """
        return any([x in key for x in inspected_attributes])

    def scan_resource_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
        self.handle_dynamic_values(conf)
        inspected_key = self.get_inspected_key()
        expected_values = self.get_expected_values()
        if dpath.search(conf, inspected_key) != {}:
            # Inspected key exists
            if ANY_VALUE in expected_values:
                # Key is found on the configuration - if it accepts any value, the check is PASSED
                return CheckResult.PASSED
            value = dpath.get(conf, inspected_key)
            if isinstance(value, list) and len(value) == 1:
                value = value[0]
            if self._is_variable_dependant(value):
                # If the tested attribute is variable-dependant, then result is PASSED
                return CheckResult.PASSED
            if value in expected_values:
                return CheckResult.PASSED
            return CheckResult.FAILED
        else:
            # Look for the configuration in a bottom-up fashion
            inspected_attributes = self._filter_key_path(inspected_key)
            for attribute in reversed(inspected_attributes):
                for sub_key, sub_conf in dpath.search(conf, f"**/{attribute}", yielded=True):
                    filtered_sub_key = self._filter_key_path(sub_key)
                    # Only proceed with check if full path for key is similar - not partial match
                    if inspected_attributes == filtered_sub_key:
                        if self._is_nesting_key(inspected_attributes, filtered_sub_key):
                            if isinstance(sub_conf, list) and len(sub_conf) == 1:
                                sub_conf = sub_conf[0]
                            if sub_conf in self.get_expected_values():
                                return CheckResult.PASSED
                            if self._is_variable_dependant(sub_conf):
                                # If the tested attribute is variable-dependant, then result is PASSED
                                return CheckResult.PASSED

        return self.missing_block_result

    @abstractmethod
    def get_inspected_key(self) -> str:
        """
        :return: JSONPath syntax path of the checked attribute
        """
        raise NotImplementedError()

    def get_expected_values(self) -> List[Any]:
        """
        Override the method with the list of acceptable values if the check has more than one possible expected value, given
        the inspected key
        :return: List of expected values, defaults to a list of the expected value
        """
        return [self.get_expected_value()]

    def get_expected_value(self) -> Any:
        """
        Returns the default expected value, governed by provider best practices
        """
        return True

    def get_evaluated_keys(self) -> List[str]:
        return force_list(self.get_inspected_key())



import re

from checkov.common.models.enums import CheckResult
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck

# Default Compute -compute@developer.gserviceaccount.com
# Default App Spot @appspot.gserviceaccount.com
DEFAULT_SA = re.compile(r".*-compute@developer\.gserviceaccount\.com|.*@appspot\.gserviceaccount\.com")


class AbsGoogleIAMMemberDefaultServiceAccount(BaseResourceCheck):
    def __init__(self, name, id, categories, supported_resources):
        super().__init__(name, id, categories, supported_resources)

    def scan_resource_conf(self, conf):
        members_conf = conf['members'][0] if 'members' in conf else conf.get('member', [])
        if any(re.match(DEFAULT_SA, str(member)) for member in members_conf):
            return CheckResult.FAILED
        return CheckResult.PASSED



import configargparse

from checkov.common.util.type_forcers import convert_str_to_bool


class ExtArgumentParser(configargparse.ArgumentParser):

    def write_config_file(self, parsed_namespace, output_file_paths, exit_after=False):
        """
        Write the given settings to output files. Overrides write_config_file from the class ArgumentParser for
        correcting types of some attributes (example: check, skip_check)

        :param parsed_namespace: namespace object created within parse_known_args()
        :param output_file_paths: any number of file paths to write the config to
        :param exit_after: whether to exit the program after writing the config files
        """
        for output_file_path in output_file_paths:
            # validate the output file path
            try:
                with self._config_file_open_func(output_file_path, "w") as output_file:
                    pass
            except IOError as e:
                raise ValueError("Couldn't open {} for writing: {}".format(
                    output_file_path, e))
        if output_file_paths:
            # generate the config file contents
            config_items = self.get_items_for_config_file_output(
                self._source_to_settings, parsed_namespace)
            # convert check and skip_check to list
            if 'check' in config_items.keys():
                config_items['check'] = config_items['check'][0].split(",")
            if 'skip-check' in config_items.keys():
                config_items['skip-check'] = config_items['skip-check'][0].split(",")
            # convert strings to booleans
            for k in config_items.keys():
                config_items[k] = convert_str_to_bool(config_items[k])

            file_contents = self._config_file_parser.serialize(config_items)
            for output_file_path in output_file_paths:
                with self._config_file_open_func(output_file_path, "w") as output_file:
                    output_file.write(file_contents)
            message = "Wrote config file to " + ", ".join(output_file_paths)
            if exit_after:
                self.exit(0, message)
            else:
                print(message)




import logging
import os
import platform
import stat
import requests
from datetime import datetime, timedelta

from checkov.common.bridgecrew.platform_integration import bc_integration
from checkov.common.bridgecrew.integration_features.base_integration_feature import BC_API_URL
from checkov.common.util.dict_utils import merge_dicts
from checkov.common.util.http_utils import get_auth_header, get_default_get_headers, get_default_post_headers


class DockerImageScanningIntegration:
    docker_image_scanning_base_url = f"{BC_API_URL}/vulnerabilities/docker-images"

    def get_bc_api_key(self):
        return bc_integration.bc_api_key

    def get_proxy_address(self):
        return f"{self.docker_image_scanning_base_url}/twistcli/proxy"

    def download_twistcli(self, cli_file_name):
        os_type = platform.system().lower()
        headers = merge_dicts(
            get_default_get_headers(bc_integration.bc_source, bc_integration.bc_source_version),
            get_auth_header(bc_integration.bc_api_key)
        )
        response = requests.request('GET', f"{self.docker_image_scanning_base_url}/twistcli/download?os={os_type}", headers=headers)
        open(cli_file_name, 'wb').write(response.content)
        st = os.stat(cli_file_name)
        os.chmod(cli_file_name, st.st_mode | stat.S_IEXEC)
        logging.debug(f'TwistCLI downloaded and has execute permission')

    def report_results(self, docker_image_name, dockerfile_path, dockerfile_content, twistcli_scan_result):
        headers = merge_dicts(
            get_default_post_headers(bc_integration.bc_source, bc_integration.bc_source_version),
            get_auth_header(bc_integration.bc_api_key)
        )
        vulnerabilities = list(map(lambda x: {
            'cveId': x['id'],
            'status': x.get('status', 'open'),
            'severity': x['severity'],
            'packageName': x['packageName'],
            'packageVersion': x['packageVersion'],
            'link': x['link'],
            'cvss': x.get('cvss'),
            'vector': x.get('vector'),
            'description': x.get('description'),
            'riskFactors': x.get('riskFactors'),
            'publishedDate': x.get('publishedDate') or (datetime.now() - timedelta(days=x.get('publishedDays', 0))).isoformat()
        }, twistcli_scan_result['results'][0].get('vulnerabilities', [])))
        payload = {
            'sourceId': bc_integration.repo_id,
            'branch': bc_integration.repo_branch,
            'dockerImageName': docker_image_name,
            'dockerFilePath': dockerfile_path,
            'dockerFileContent': dockerfile_content,
            'sourceType': bc_integration.bc_source,
            'vulnerabilities': vulnerabilities
        }
        response = requests.request('POST', f"{self.docker_image_scanning_base_url}/report", headers=headers, json=payload)
        response.raise_for_status()

docker_image_scanning_integration = DockerImageScanningIntegration()



import json
import logging
import os
from abc import abstractmethod

from checkov.common.bridgecrew.integration_features.integration_feature_registry import integration_feature_registry
from checkov.common.output.report import Report
from checkov.common.util import dict_utils
from checkov.terraform.context_parsers.registry import parser_registry
from checkov.terraform.runner import Runner as tf_runner
from checkov.terraform.parser import Parser


CHECK_BLOCK_TYPES = frozenset(["resource", "data", "provider", "module"])
OUTPUT_CHOICES = ['cli', 'json', 'junitxml', 'github_failed_only']

from checkov.common.bridgecrew.platform_integration import bc_integration

class RunnerRegistry(object):
    runners = []
    scan_reports = []
    banner = ""

    def __init__(self, banner, runner_filter, *runners):
        self.logger = logging.getLogger(__name__)
        self.runner_filter = runner_filter
        self.runners = runners
        self.banner = banner
        self.scan_reports = []
        self.filter_runner_framework()

    @abstractmethod
    def extract_entity_details(self, entity):
        raise NotImplementedError()

    def run(self, root_folder=None, external_checks_dir=None, files=None, guidelines=None, collect_skip_comments=True, repo_root_for_plan_enrichment=None):
        for runner in self.runners:
            integration_feature_registry.run_pre_scan()
            scan_report = runner.run(root_folder, external_checks_dir=external_checks_dir, files=files,
                                     runner_filter=self.runner_filter, collect_skip_comments=collect_skip_comments)
            integration_feature_registry.run_post_scan(scan_report)
            if guidelines:
                RunnerRegistry.enrich_report_with_guidelines(scan_report, guidelines)
            if repo_root_for_plan_enrichment:
                enriched_resources = RunnerRegistry.get_enriched_resources(repo_root_for_plan_enrichment)
                enriched_report = Report("terraform_plan").enrich_plan_report(scan_report, enriched_resources)
                enriched_report_with_skipped = Report("terraform_plan").handle_skipped_checks(enriched_report, enriched_resources)
                self.scan_reports.append(enriched_report_with_skipped)
            else:
                self.scan_reports.append(scan_report)
        return self.scan_reports

    def print_reports(self, scan_reports, config, url=None):
        if config.output == 'cli':
            print(f"{self.banner}\n")
        exit_codes = []
        report_jsons = []
        junit_reports = []
        for report in scan_reports:
            if not report.is_empty():
                if config.output == "json":
                    report_jsons.append(report.get_dict(is_quiet=config.quiet))
                elif config.output == "junitxml":
                    junit_reports.append(report)
                    # report.print_junit_xml()
                elif config.output == 'github_failed_only':
                    report.print_failed_github_md()
                else:
                    report.print_console(is_quiet=config.quiet, is_compact=config.compact)
                    if url:
                        print("More details: {}".format(url))
            exit_codes.append(report.get_exit_code(config.soft_fail))
        if config.output == "junitxml":
            if len(junit_reports) == 1:
                junit_reports[0].print_junit_xml()
            else:
                master_report = Report(None)
                for report in junit_reports:
                    master_report.skipped_checks += report.skipped_checks
                    master_report.passed_checks += report.passed_checks
                    master_report.failed_checks += report.failed_checks
                master_report.print_junit_xml()
        if config.output == "json":
            if len(report_jsons) == 1:
                print(json.dumps(report_jsons[0], indent=4))
            else:
                print(json.dumps(report_jsons, indent=4))
        #if config.output == "cli":
            #bc_integration.get_report_to_platform(config,scan_reports)

        exit_code = 1 if 1 in exit_codes else 0
        return exit_code

    def filter_runner_framework(self):
        if not self.runner_filter:
            return
        if self.runner_filter.framework is None:
            return
        if self.runner_filter.framework == 'all':
            return
        filtered_runners = []
        for runner in self.runners:
            if runner.check_type in self.runner_filter.framework:
                filtered_runners.append(runner)
        self.runners = filtered_runners
        return

    @staticmethod
    def enrich_report_with_guidelines(scan_report, guidelines):
        for record in scan_report.failed_checks + scan_report.passed_checks + scan_report.skipped_checks:
            if record.check_id in guidelines:
                record.set_guideline(guidelines[record.check_id])

    @staticmethod
    def get_enriched_resources(repo_root):
        tf_definitions = {}
        parsing_errors = {}
        Parser().parse_directory(
            directory=repo_root,  # assume plan file is in the repo-root
            out_definitions=tf_definitions,
            out_parsing_errors=parsing_errors,
        )

        enriched_resources = {}
        for full_file_path, definition in tf_definitions.items():
            definitions_context = parser_registry.enrich_definitions_context((full_file_path, definition))
            abs_scanned_file, _ = tf_runner._strip_module_referrer(full_file_path)
            scanned_file = os.path.relpath(abs_scanned_file, repo_root)
            for block_type, block_value in definition.items():
                if block_type in CHECK_BLOCK_TYPES:
                    for entity in block_value:
                        context_parser = parser_registry.context_parsers[block_type]
                        definition_path = context_parser.get_entity_context_path(entity)
                        entity_id = ".".join(definition_path)
                        entity_context_path = [block_type] + definition_path
                        entity_context = dict_utils.getInnerDict(
                            definitions_context[full_file_path], entity_context_path
                        )
                        entity_lines_range = [
                            entity_context.get("start_line"),
                            entity_context.get("end_line"),
                        ]
                        entity_code_lines = entity_context.get("code_lines")
                        skipped_checks = entity_context.get("skipped_checks")
                        enriched_resources[entity_id] = {
                            "entity_code_lines": entity_code_lines,
                            "entity_lines_range": entity_lines_range,
                            "scanned_file": scanned_file,
                            "skipped_checks": skipped_checks
                        }
        return enriched_resources



class Edge:
    def __init__(self, origin: int, dest: int, label: str) -> None:
        self.origin = origin
        self.dest = dest
        self.label = label

    def __str__(self) -> str:
        return f"[{self.origin} -({self.label})-> {self.dest}]"



from checkov.common.models.consts import ANY_VALUE
from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.terraform.checks.resource.base_resource_negative_value_check import BaseResourceNegativeValueCheck


class StorageAccountDisablePublicAccess(BaseResourceNegativeValueCheck):
    def __init__(self):
        name = "Ensure that Storage accounts disallow public access"
        id = "CKV_AZURE_59"
        supported_resources = ['azurerm_storage_account']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "allow_blob_public_access"

    def get_forbidden_values(self):
        return [True]

check = StorageAccountDisablePublicAccess()



from termcolor import colored

from checkov.version import version
from checkov.common.version_manager import check_for_update

banner = r"""
       _               _              
   ___| |__   ___  ___| | _______   __
  / __| '_ \ / _ \/ __| |/ / _ \ \ / /
 | (__| | | |  __/ (__|   < (_) \ V / 
  \___|_| |_|\___|\___|_|\_\___/ \_/  
                                      
By bridgecrew.io | version: {} """.format(version)

new_version = check_for_update("checkov", version)
if new_version:
    banner = "\n" + banner + "\nUpdate available " + colored(version,"grey") + " -> " + colored(new_version, "green") + "\nRun " + colored(
        "pip3 install -U checkov", "magenta") + " to update \n"




from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.kubernetes.base_spec_check import BaseK8Check


class KubletEventCapture(BaseK8Check):
    def __init__(self):
        # CIS-1.6 4.2.9
        id = "CKV_K8S_147"
        name = "Ensure that the --event-qps argument is set to 0 or a level which ensures appropriate event capture"
        categories = [CheckCategories.KUBERNETES]
        supported_entities = ['containers']
        super().__init__(name=name, id=id, categories=categories,
                         supported_entities=supported_entities)

    def get_resource_id(self, conf):
        return f'{conf["parent"]} - {conf["name"]}'

    def scan_spec_conf(self, conf):
        if "command" in conf:
            if "kubelet" in conf["command"]:
                for cmd in conf["command"]:
                    if "=" in cmd:
                        [key, value, *_] = cmd.split("=")
                        if key == "--event-qps":
                            if int(value) > 5:
                                return CheckResult.FAILED

        return CheckResult.PASSED


check = KubletEventCapture()



from networkx.classes.digraph import DiGraph

from checkov.common.graph.checks_infra.enums import Operators
from checkov.terraform.checks_infra.solvers.connections_solvers.complex_connection_solver import ComplexConnectionSolver
from checkov.terraform.graph_builder.graph_components.attribute_names import CustomAttributes


class AndConnectionSolver(ComplexConnectionSolver):
    operator = Operators.AND

    def __init__(self, solvers, operator):
        super().__init__(solvers, operator)

    def get_operation(self, graph_connector: DiGraph):
        passed_attributes, failed_attributes = self.run_attribute_solvers(graph_connector)
        passed_attributes = [p for p in passed_attributes if
                             p[CustomAttributes.ID] not in [f[CustomAttributes.ID] for f in failed_attributes]]
        passed, failed = passed_attributes, failed_attributes
        connection_solvers = self.get_sorted_connection_solvers()
        passed_connections, failed_connections = [], []
        for connection_solver in connection_solvers:
            connection_solver.set_vertices(graph_connector, failed_attributes+failed_connections)
            passed_solver, failed_solver = connection_solver.get_operation(graph_connector)
            passed_connections.extend(passed_solver)
            failed_connections.extend(failed_solver)
            passed_connections = [p for p in passed_connections if
                      p[CustomAttributes.ID] not in [f[CustomAttributes.ID] for f in failed_connections]]

        passed.extend(passed_connections)
        failed.extend(failed_connections)
        passed = [p for p in passed if
                              p[CustomAttributes.ID] not in [f[CustomAttributes.ID] for f in failed]]
        passed = [p for p in passed if
                  p[CustomAttributes.ID] in [pt[CustomAttributes.ID] for pt in passed_attributes] and p[
                      CustomAttributes.ID] in [pt[CustomAttributes.ID] for pt in passed_connections]]

        return self.filter_results(passed, failed)

    def _get_operation(self, *args, **kwargs):
        pass






from checkov.common.models.consts import ANY_VALUE
from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class DataFactoryUsesGitRepository(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that Azure Data Factory uses Git repository for source control"
        id = "CKV_AZURE_103"
        supported_resources = ['azurerm_data_factory']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "github_configuration/[0]/repository_name"

    def get_expected_value(self):
        return ANY_VALUE


check = DataFactoryUsesGitRepository()



from checkov.common.models.consts import ANY_VALUE
from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class CloudfrontDistributionLogging(BaseResourceValueCheck):

    def __init__(self):
        name = "Ensure Cloudfront distribution has Access Logging enabled"
        id = "CKV_AWS_86"
        supported_resources = ['aws_cloudfront_distribution']
        categories = [CheckCategories.LOGGING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return "logging_config/[0]/bucket"

    def get_expected_value(self):
        return ANY_VALUE


check = CloudfrontDistributionLogging()
